/*==============================================================================*/
/*  Copyright (C) 2009-2016, Heartland Data inc. All Rights Reserved.           */
/*                                                                              */
/*  Title  :   Android Framework Data Writing Driver                            */
/*  EventID:   Via the driver                                                   */
/*  AppVer :   DT10 Ver10.XX`@                                                */
/*  FileID :   43b                                                              */
/*  Version:   2.1                                                              */
/*  Author :   HLDC                                                             */
/*==============================================================================*/
/*==============================================================================*/
/*  Desc:   Header for File IO                                                  */
/*==============================================================================*/
#include <stdio.h>
#include <sys/types.h>
#include <fcntl.h>
#include <string.h>
#include <unistd.h>

/*==============================================================================*/
/*  Macro:  DT_UINT                                                             */
/*  Desc:   Please change Test Point argument type for DT10 Project setting.    */
/*==============================================================================*/
#define	DT_UINT unsigned int

/*==============================================================================*/
/*  Macro:  DT10_DRV                                                            */
/*  Desc:   Register Proc file name for Linux.                                  */
/*==============================================================================*/
#define 	DT10_DRV "/proc/dt10proc"

/*==============================================================================*/
/*  Struct: DT10_DATA                                                           */
/*  Desc:   Test Point data.                                                    */
/*==============================================================================*/
struct DT10_DATA {
	char tp_func;
	DT_UINT addr;
	DT_UINT dat;
	DT_UINT size;
	unsigned char value[256];
};

/*==============================================================================*/
/*  Desc:   DT10_DATA.tp_func ID                                                */
/*==============================================================================*/
#define TP_BusOut			'3'
#define TP_MemoryOutput		'4'

static int fd = -1;

/*==============================================================================*/
/*  Func:   _TP_BusOut                                                          */
/*  Desc:   Called by Test Point                                                */
/*==============================================================================*/
void _TP_BusOut( DT_UINT addr, DT_UINT data )
{
	struct DT10_DATA dt10_data;

	if (fd < 0) {
		fd = open(DT10_DRV, O_RDWR);
		if (fd <= 0) {
			return;
		}
	}

	dt10_data.tp_func = TP_BusOut;
	dt10_data.addr = addr;
	dt10_data.dat = data;

	write(fd, &dt10_data, sizeof(dt10_data));
}

/*==============================================================================*/
/*  Func:   _TP_MemoryOutput                                                    */
/*  Desc:   Called by Variable TestPoint                                        */
/*==============================================================================*/
void _TP_MemoryOutput( DT_UINT addr, DT_UINT data, void *value, DT_UINT size)
{
	struct DT10_DATA dt10_data;

	if (fd < 0) {
		fd = open(DT10_DRV, O_RDWR);
		if (fd <= 0) {
			return;
		}
	}

	if (size > 256) size = 256;
	dt10_data.tp_func = TP_MemoryOutput;
	dt10_data.addr = addr;
	dt10_data.dat = data;
	dt10_data.size = size;
	memcpy(dt10_data.value, value, size);

	write(fd, &dt10_data, sizeof(dt10_data));
}
